{
	"name" : "Localisation for Switzerland",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Localisation/Europe",
	"depends" : ["base", "account"],
	"init_xml" : [],
	"demo_xml" : ["account_demo.xml"],
	"update_xml" : ["account_pcg_switzerland.xml"],
	"active": False
}
